package
Version:
v0.5.1
Opens a new window with list of versions in this module.
Published: Dec 20, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Result struct {
ID string `json:"id"`
OldName string `json:"old_name"`
NewName string `json:"new_name"`
URL string `json:"url"`
Applied bool `json:"applied"`
Skipped bool `json:"skipped,omitempty"`
SkipReason string `json:"skip_reason,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.