Documentation
¶
Index ¶
- func CreateReportNote() string
- func GenerateTimestamp() string
- func UploadReport(ctx context.Context, client *workflowy.WorkflowyClient, report ReportOutput, ...) (string, error)
- type ChildrenCountReportOutput
- type CountReportOutput
- type CreatedReportOutput
- type ModifiedReportOutput
- type ReportOutput
- type UploadOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateReportNote ¶
func CreateReportNote() string
CreateReportNote creates a standard report note with generation time
func GenerateTimestamp ¶
func GenerateTimestamp() string
GenerateTimestamp returns a formatted timestamp for report titles
func UploadReport ¶
func UploadReport(ctx context.Context, client *workflowy.WorkflowyClient, report ReportOutput, opts UploadOptions) (string, error)
UploadReport uploads a report to Workflowy
Types ¶
type ChildrenCountReportOutput ¶
type ChildrenCountReportOutput struct {
Ranked []workflowy.ChildrenCountRankable
TopN int
}
ChildrenCountReportOutput wraps children count ranking results
func (*ChildrenCountReportOutput) Title ¶
func (r *ChildrenCountReportOutput) Title() string
Title returns the report title
type CountReportOutput ¶
type CountReportOutput struct {
RootItem *workflowy.Item
Descendants workflowy.Descendants
Threshold float64
}
CountReportOutput wraps descendant count results for conversion to nodes
func (*CountReportOutput) Title ¶
func (c *CountReportOutput) Title() string
Title returns the report title
type CreatedReportOutput ¶
type CreatedReportOutput struct {
Ranked []workflowy.TimestampRankable
TopN int
}
CreatedReportOutput wraps created date ranking results
func (*CreatedReportOutput) Title ¶
func (r *CreatedReportOutput) Title() string
Title returns the report title
type ModifiedReportOutput ¶
type ModifiedReportOutput struct {
Ranked []workflowy.TimestampRankable
TopN int
}
ModifiedReportOutput wraps modified date ranking results
func (*ModifiedReportOutput) Title ¶
func (r *ModifiedReportOutput) Title() string
Title returns the report title
type ReportOutput ¶
type ReportOutput interface {
// ToNodes converts the report to a tree of Workflowy items
ToNodes() (*workflowy.Item, error)
// Title returns the report title
Title() string
}
ReportOutput represents a report that can be converted to Workflowy nodes
type UploadOptions ¶
type UploadOptions struct {
ParentID string // Where to create the report (default: "None" = root)
Position string // "top" or "bottom" (optional)
}
UploadOptions configures where and how to upload a report